@@ -10,7 +10,7 @@ class ContractBindingGenerator:
         self.remappings = remappings
         self.sources = sources
         self.allow_paths = allow_paths
-        self.template = """from typing import Optional, Union
+        self.template = """from typing import Optional, Union, List
 from eth_typing import Address, ChecksumAddress
 from web3 import Web3
 from web3.types import TxParams
@@ -31,10 +31,16 @@ class ContractAddressNotSet(Exception):
             'bytes32': 'bytes',
             'int8': 'int',
             'tuple': 'tuple',
-            'uint8': 'int'
+            'uint8': 'int',
+            'string': 'str'
         }
 
-        return sol_type_to_py_type.get(t, None)
+        if '[' in t:
+            base_type = t.split('[')[0]
+            list_type = sol_type_to_py_type.get(base_type, 'str')
+            return f'List[{list_type}]'
+        else:
+            return sol_type_to_py_type.get(t, None)
 
     @staticmethod
     def camel_to_snake(camel):
@@ -71,6 +77,7 @@ class ContractAddressNotSet(Exception):
 
         output = compile_files(self.sources, output_values=["abi", "bin-runtime", "bin"],
                                import_remappings=self.remappings, allow_paths=self.allow_paths)
+
         for key, val in output.items():
             contract_name = key.split(':')[1]
             file_name = f"{re.sub(r'(?<!^)(?=[A-Z])', '_', contract_name).lower()}.py"
@@ -98,6 +105,8 @@ class ContractAddressNotSet(Exception):
         self.address = tx_receipt.contractAddress
         """
 
+            seen_methods = set()
+
             for elem in abi:
                 ty = elem.get('type')
                 inputs = elem.get('inputs', [])
@@ -113,6 +122,14 @@ class ContractAddressNotSet(Exception):
         """
                 elif ty == 'function':
                     func_name = elem.get('name')
+
+                    # we can take the first instance of the method because this is the instance that was
+                    # defined in the top level contract
+                    if func_name in seen_methods:
+                        continue
+
+                    seen_methods.add(func_name)
+
                     state_mutability = elem.get('stateMutability')
                     outputs = elem.get('outputs', [])
                     return_type = ContractBindingGenerator.outputs_to_return_type(outputs)
@@ -121,12 +138,11 @@ class ContractAddressNotSet(Exception):
                     if state_mutability != 'view':
                         statement_args += ', override_tx_parameters: Optional[TxParams] = None'
                         return_stmt = f'{return_stmt}.build_transaction(override_tx_parameters)'
-                    else:
-                        return_stmt = f'{return_stmt}.build_transaction()'
-
-                    if state_mutability == 'view' and return_type:
+                    elif state_mutability == 'view' and return_type:
                         return_type_string = f' -> {return_type}'
                         return_stmt = f"return c.functions.{func_name}({pass_into_method}).call()"
+                    else:
+                        return_stmt = f'{return_stmt}.build_transaction()'
 
                     code += f"""\n    def {ContractBindingGenerator.camel_to_snake(func_name)}({statement_args}){return_type_string}:"""
                     code += """\n        if not self.address:
