@@ -1,4 +1,7 @@
 from typing import TypedDict, Optional, List
+
+from eth_typing import ChecksumAddress
+
 from eulith_web3.erc20 import EulithERC20
 
 
@@ -24,3 +27,12 @@ class EulithAaveV2InnerLoanBody(TypedDict):
 
 class EulithAaveV2StartLoanRequest(TypedDict):
     tokens: List[EulithAaveV2InnerLoanBody]
+
+
+# ~~~~~~~~~~~~ FLASH ~~~~~~~~~~~~~~~~~~~
+class FlashRequest(TypedDict):
+    take: EulithERC20
+    pay: EulithERC20
+    take_amount: float
+    recipient: Optional[ChecksumAddress]
+    pay_transfer_from: Optional[ChecksumAddress]
\ No newline at end of file
